#
# spec file for package python-django-phonenumber-field
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-django-phonenumber-field
Version:        8.0.0
Release:        1.3
Summary:        International phone number field for django models
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/stefanfoulis/django-phonenumber-field
Source:         https://files.pythonhosted.org/packages/source/d/django_phonenumber_field/django_phonenumber_field-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Babel
Requires:       python-Django >= 4.2
Recommends:     python-phonenumbers >= 7.0.2
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Babel}
BuildRequires:  %{python_module Django >= 4.2}
BuildRequires:  %{python_module django-rest-framework}
BuildRequires:  %{python_module phonenumbers >= 7.0.2}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
An international phone number field for django models.

%prep
%setup -q -n django_phonenumber_field-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export LANG=en_US.UTF-8
%python_exec -m django test --settings=tests.settings

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/phonenumber_field
%{python_sitelib}/django_phonenumber_field-%{version}*-info

%changelog
* Mon Nov 11 2024 Markéta Machová <mmachova@suse.com>
- Update to 8.0.0
  Breaking Changes:
  * formfields.PhoneNumberField with a region now display national phone
    numbers in the national format instead of PHONENUMBER_DEFAULT_FORMAT.
  * Add a DB converter for the model field, fixing values_list() of
    PhoneNumberField
  * RegionalPhoneNumberWidget becomes the default widget for the
    formfields.PhoneNumberField.
  * The formfields.PhoneNumberField no longer sets the input_type attribute
    of its widget to tel. That behavior did not make sense for the existing
    PhoneNumberPrefixWidget and was dropped.
  * Remove PhoneNumberInternationalFallbackWidget. Use
    phonenumber_field.widgets.RegionalPhoneNumberWidget instead.
  * Move validation from widgets to the form fields.
  Some Changes:
  * Add support for Django 5.0
  * Drop support for Django 4.1
  * Drop support for Python 3.7
  * Add support for Python 3.12
  * Restore PhoneNumberPrefixWidget number input on form errors
  * Set PhoneNumberInternationalFallbackWidget input_type to tel
  * Evolve PhoneNumberInternationalWidget to RegionalPhoneNumberWidget
* Tue Oct 24 2023 Dirk Müller <dmueller@suse.com>
- use setuptools_scm to get proper version in metadata
* Fri Jan  7 2022 John Vandenberg <jayvdb@gmail.com>
- Skip Tumbleweed Python 3.6 incompatible with Django 4
* Wed May 26 2021 Markéta Machová <mmachova@suse.com>
- Update to 5.1.0
  * Add support for Python 3.9 and Django 3.2
  * Allow sorting PhoneNumbers from Python
  * Drop support for end-of-life Django 1.11 and 2.1.
* Sat Jun 27 2020 John Vandenberg <jayvdb@gmail.com>
- Activate test suite
* Wed Apr 15 2020 John Vandenberg <jayvdb@gmail.com>
- Update to v4.0.0
* Fri Apr 12 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v2.3.1
